{% extends "layout.html" %}
{% block title %}Create Profile{% endblock %}
{% block body %}
  <h2>Create Profile</h2>
  <p>
    Hey!  This is the first time you signed in on this website.  In
    order to proceed we need some extra information from you:
  <form action="" method=post>
    <dl>
      <dt>Name:
      <dd><input type=text name=name size=30 value="{{ request.values.name }}">
      <dt>E-Mail:
      <dd><input type=text name=email size=30 value="{{ request.values.email }}">
    </dl>
    <p>
      <input type=submit value="Create profile">
      <input type=hidden name=next value="{{ next }}">
  </form>
  <p>
    If you don't want to proceed, you can <a href="{{ url_for('logout')
    }}">sign out</a> again.
{% endblock %}
