{% extends "layout.html" %}
{% block title %}Edit Profile{% endblock %}
{% block body %}
  <h2>Edit Profile</h2>
  <form action="" method=post>
    <dl>
      <dt>Name:
      <dd><input type=text name=name size=30 value="{{ form.name }}">
      <dt>E-Mail
      <dd><input type=text name=email size=30 value="{{ form.email }}">
    </dl>
    <p>
      <input type=submit value="Update profile">
      <input type=submit name=delete value="Delete">
  </form>
{% endblock %}
